RouteflyQuery class

Route Parameters

Constructors

RouteflyQuery(Map<String, String> params, Map<String, dynamic> _data, dynamic arguments)
Route Parameters

Properties

arguments → dynamic
Route arguments
final
hashCode int
The hash code for this object.
no setterinherited
params Map<String, String>
Get url params
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String key) → dynamic
Get query of dynamic routes